@@ -1,26 +1,13 @@
 -- 
 -- Created by SQL::Translator::Producer::MySQL
--- Created on Thu May 11 17:10:18 2017
+-- Created on Thu May 11 15:06:58 2017
 -- 
 SET foreign_key_checks=0;
 
-DROP TABLE IF EXISTS `test_report`;
-
---
--- Table: `test_report`
---
-CREATE TABLE `test_report` (
-  `id` char(36) NOT NULL,
-  `report` JSON NOT NULL,
-  PRIMARY KEY (`id`)
-);
-
-DROP TABLE IF EXISTS `uploads`;
-
 --
 -- Table: `uploads`
 --
-CREATE TABLE `uploads` (
+CREATE TABLE IF NOT EXISTS `uploads` (
   `uploadid` integer unsigned NOT NULL auto_increment,
   `type` varchar(255) NOT NULL,
   `author` varchar(255) NOT NULL,
@@ -31,38 +18,34 @@ CREATE TABLE `uploads` (
   PRIMARY KEY (`uploadid`)
 ) ENGINE=InnoDB;
 
-DROP TABLE IF EXISTS `cpanstats`;
-
 --
 -- Table: `cpanstats`
 --
-CREATE TABLE `cpanstats` (
+CREATE TABLE IF NOT EXISTS `cpanstats` (
   `id` integer unsigned NOT NULL auto_increment,
   `guid` char(36) NOT NULL,
   `state` enum('pass', 'fail', 'unknown', 'na') NOT NULL,
   `postdate` mediumint unsigned NOT NULL,
-  `tester` varchar(100) NOT NULL,
-  `dist` varchar(100) NOT NULL,
-  `version` varchar(20) NOT NULL,
-  `platform` varchar(20) NOT NULL,
-  `perl` varchar(10) NOT NULL,
-  `osname` varchar(20) NOT NULL,
-  `osvers` varchar(20) NOT NULL,
-  `fulldate` char(8) NOT NULL,
+  `tester` varchar(255) NOT NULL,
+  `dist` varchar(255) NOT NULL,
+  `version` varchar(255) NOT NULL,
+  `platform` varchar(255) NOT NULL,
+  `perl` varchar(255) NOT NULL,
+  `osname` varchar(255) NOT NULL,
+  `osvers` varchar(255) NOT NULL,
+  `fulldate` varchar(32) NOT NULL,
   `type` tinyint unsigned NOT NULL,
   `uploadid` integer unsigned NOT NULL,
   INDEX `cpanstats_idx_uploadid` (`uploadid`),
   PRIMARY KEY (`id`),
-  UNIQUE `cpanstats_guid` (`guid`),
+  UNIQUE KEY (`guid`),
   CONSTRAINT `cpanstats_fk_uploadid` FOREIGN KEY (`uploadid`) REFERENCES `uploads` (`uploadid`)
 ) ENGINE=InnoDB;
 
-DROP TABLE IF EXISTS `ixlatest`;
-
 --
 -- Table: `ixlatest`
 --
-CREATE TABLE `ixlatest` (
+CREATE TABLE IF NOT EXISTS `ixlatest` (
   `dist` varchar(255) NOT NULL,
   `author` varchar(255) NOT NULL,
   `version` varchar(255) NOT NULL,
@@ -74,12 +57,10 @@ CREATE TABLE `ixlatest` (
   CONSTRAINT `ixlatest_fk_uploadid` FOREIGN KEY (`uploadid`) REFERENCES `uploads` (`uploadid`)
 ) ENGINE=InnoDB;
 
-DROP TABLE IF EXISTS `release_data`;
-
 --
 -- Table: `release_data`
 --
-CREATE TABLE `release_data` (
+CREATE TABLE IF NOT EXISTS `release_data` (
   `dist` varchar(255) NOT NULL,
   `version` varchar(255) NOT NULL,
   `id` integer NOT NULL,
@@ -98,12 +79,10 @@ CREATE TABLE `release_data` (
   CONSTRAINT `release_data_fk_uploadid` FOREIGN KEY (`uploadid`) REFERENCES `uploads` (`uploadid`)
 ) ENGINE=InnoDB;
 
-DROP TABLE IF EXISTS `release_summary`;
-
 --
 -- Table: `release_summary`
 --
-CREATE TABLE `release_summary` (
+CREATE TABLE IF NOT EXISTS `release_summary` (
   `dist` varchar(255) NOT NULL,
   `version` varchar(255) NOT NULL,
   `id` integer NOT NULL,
